/*
 * $Id: imap_acl.h 8378 2010-02-25 22:43:57Z dothebart $
 *
 *
 * Copyright (c) 2007-2009 by the citadel.org team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

void imap_setacl(int num_parms, ConstStr *Params);
void imap_deleteacl(int num_parms, ConstStr *Params);
void imap_getacl(int num_parms, ConstStr *Params);
void imap_listrights(int num_parms, ConstStr *Params);
void imap_myrights(int num_parms, ConstStr *Params);

